@@ -8,5 +8,7 @@ SIZE_CHOICES = [
 ]
 
 class Dashboard(Model):
+    target = models.CharField(max_length=20, default='default')
     size = models.CharField(max_length=1, choices=SIZE_CHOICES, default='1')
+    background = models.BooleanField(default=True)
     content = models.TextField()
